package com.antai.sport.http.server.server.api.business.achievement.service;

import com.antai.sport.http.server.constants.AchievementCondition;
import com.antai.sport.http.server.constants.GameCurrencySourceType;
import com.antai.sport.http.server.repository.achievement.entity.Achievement;
import com.antai.sport.http.server.repository.achievement.entity.AchievementForSportUser;
import com.antai.sport.http.server.repository.achievement.mapper.AchievementForSportUserMapper;
import com.antai.sport.http.server.server.api.business.achievement.mapper.AchievementBizMapper;
import com.antai.sport.http.server.server.api.business.sportusergamecurrency.service.SportUserGameCurrencyService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

@Service
public class AchievementService {

    @Resource
    private AchievementForSportUserMapper achievementForSportUserMapper;

    @Resource
    private AchievementBizMapper achievementBizMapper;

    @Resource
    private SportUserGameCurrencyService sportUserGameCurrencyService;

    /**
     * 处理签到类成就
     *
     * @param sportUserId
     */
    public void handleSignInAchievement(Long sportUserId, Integer continuousLoginDays) {
        List<Achievement> achievementList =
                achievementBizMapper.getSignInAchievement(AchievementCondition.SIGN_IN_DAYS, sportUserId);
        for (Achievement achievement : achievementList) {
            if (continuousLoginDays.compareTo(achievement.getConditionValue()) >= 0) {
                AchievementForSportUser achievementForSportUser = new AchievementForSportUser();
                achievementForSportUser.setSportUserId(sportUserId);
                achievementForSportUser.setAchievementId(achievement.getId());
                achievementForSportUser.setMarkRead(false);
                achievementForSportUser.setCreateTime(LocalDateTime.now());
                achievementForSportUserMapper.insert(achievementForSportUser);
                sportUserGameCurrencyService.addCurrency(sportUserId, achievement.getCurrency(),
                        GameCurrencySourceType.ACHIEVEMENT, achievement.getId());
            }
        }
    }

}
